// @flow

import React from 'react'
import cn from 'classnames'

const Article = ({
  post: {
    title,
    headerColor,
    author,
    image,
    body,
  },
}: {
  post: TPost,
}) => {
  const style = image ? {
    background: `linear-gradient(rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.5)), url(${image})`,
  } : {}
  return (
    <article>
      <header className={cn('relative w-100 cover', headerColor, { 'vh-75': !!image })}>
        {/* Split into 2 components for easier apply effect to background image  */}
        <div
          style={style}
          className={cn('absolute aspect-ratio--object')}
        />
        <div className="absolute aspect-ratio--object v-mid ph3 ph4-m ph5-l flex flex-column justify-center">
          <h1 className="f3 f1-ns mw8 center lh-title fw9 tc">
            {title}
          </h1>
          <h2 className="f5 f4-ns fw6 center">
            {author}
          </h2>
        </div>
      </header>
      <div
        className="markdown content mw7 center mt3 mt4-ns pa3 pa3-ns"
        dangerouslySetInnerHTML={{ __html: body }}
      />
    </article>
  )
}

export default Article
