'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _recompose = require('recompose');

var _reactCssThemr = require('react-css-themr');

var _Field = require('rebulma/lib/Field');

var _Field2 = _interopRequireDefault(_Field);

var _Label = require('rebulma/lib/Label');

var _Label2 = _interopRequireDefault(_Label);

var _Input = require('rebulma/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _Help = require('rebulma/lib/Help');

var _Help2 = _interopRequireDefault(_Help);

var _Button = require('rebulma/lib/Button');

var _Button2 = _interopRequireDefault(_Button);

var _createFormReducer = require('../../utils/createFormReducer');

var _createFormReducer2 = _interopRequireDefault(_createFormReducer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultStyles = {
  label: '',
  input: '',
  button: ''
};

var ON_CHANGE = 'ON_CHANGE';

function validateField(name, value) {
  switch (name) {
    case 'name':
      if (!value) return 'Required';
      break;
    case 'email':
      if (!value) return 'Required';
      break;
    case 'phone':
      if (!value) return 'Required';
      break;
    case 'description':
      if (!value) return 'Required';
      break;
    default:
      return '';
  }
  return '';
}

var reducer = (0, _createFormReducer2.default)({ ON_CHANGE: ON_CHANGE, validateField: validateField });

var ContactForm = function ContactForm(_ref) {
  var className = _ref.className,
      nameLabel = _ref.nameLabel,
      emailLabel = _ref.emailLabel,
      phoneLabel = _ref.phoneLabel,
      descriptionLabel = _ref.descriptionLabel,
      submitLabel = _ref.submitLabel,
      _ref$state = _ref.state,
      _ref$state$name = _ref$state.name,
      name = _ref$state$name === undefined ? '' : _ref$state$name,
      _ref$state$email = _ref$state.email,
      email = _ref$state$email === undefined ? '' : _ref$state$email,
      _ref$state$phone = _ref$state.phone,
      phone = _ref$state$phone === undefined ? '' : _ref$state$phone,
      _ref$state$descriptio = _ref$state.description,
      description = _ref$state$descriptio === undefined ? '' : _ref$state$descriptio,
      _ref$state$isValid = _ref$state.isValid,
      isValid = _ref$state$isValid === undefined ? false : _ref$state$isValid,
      error = _ref$state.error,
      dispatch = _ref.dispatch,
      onSubmit = _ref.onSubmit,
      theme = _ref.theme;
  return _react2.default.createElement(
    'div',
    { className: className },
    _react2.default.createElement(
      'div',
      { className: 'hero-body' },
      _react2.default.createElement(
        _Field2.default,
        null,
        _react2.default.createElement(
          _Label2.default,
          { className: theme.label, htmlFor: 'name' },
          nameLabel
        ),
        _react2.default.createElement(_Input2.default, {
          className: theme.input,
          name: 'name',
          value: name,
          onChange: function onChange(e) {
            dispatch({ type: ON_CHANGE, payload: { name: 'name', value: e.target.value } });
          }
        }),
        error.name && _react2.default.createElement(
          _Help2.default,
          { className: 'is-danger' },
          error.name
        )
      ),
      _react2.default.createElement(
        _Field2.default,
        null,
        _react2.default.createElement(
          _Label2.default,
          { className: theme.label, htmlFor: 'email' },
          emailLabel
        ),
        _react2.default.createElement(_Input2.default, {
          className: theme.input,
          name: 'email',
          value: email,
          onChange: function onChange(e) {
            dispatch({ type: ON_CHANGE, payload: { name: 'email', value: e.target.value } });
          }
        }),
        error.email && _react2.default.createElement(
          _Help2.default,
          { className: 'is-danger' },
          error.email
        )
      ),
      _react2.default.createElement(
        _Field2.default,
        null,
        _react2.default.createElement(
          _Label2.default,
          { className: theme.label, htmlFor: 'phone' },
          phoneLabel
        ),
        _react2.default.createElement(_Input2.default, {
          className: theme.input,
          name: 'phone',
          value: phone,
          onChange: function onChange(e) {
            dispatch({ type: ON_CHANGE, payload: { name: 'phone', value: e.target.value } });
          }
        }),
        error.phone && _react2.default.createElement(
          _Help2.default,
          { className: 'is-danger' },
          error.phone
        )
      ),
      _react2.default.createElement(
        _Field2.default,
        null,
        _react2.default.createElement(
          _Label2.default,
          { className: theme.label, htmlFor: 'description' },
          descriptionLabel
        ),
        _react2.default.createElement(_Input2.default, {
          className: theme.input,
          name: 'description',
          value: description,
          onChange: function onChange(e) {
            dispatch({ type: ON_CHANGE, payload: { name: 'description', value: e.target.value } });
          }
        }),
        error.description && _react2.default.createElement(
          _Help2.default,
          { className: 'is-danger' },
          error.description
        )
      ),
      _react2.default.createElement(
        _Field2.default,
        null,
        _react2.default.createElement(
          _Button2.default,
          {
            control: true,
            disabled: !isValid,
            className: theme.button,
            onClick: function onClick() {
              if (onSubmit) onSubmit({ name: name, email: email, phone: phone, description: description });
            }
          },
          submitLabel
        )
      )
    )
  );
};

ContactForm.defaultProps = {
  children: null,
  className: null,
  nameLabel: 'Name',
  emailLabel: 'Email',
  phoneLabel: 'Phone',
  descriptionLabel: 'Description',
  submitLabel: 'Submit',
  error: {},
  onSubmit: null
};

var defaultError = {
  name: 'Required',
  email: 'Required',
  phone: 'Required',
  description: 'Required'
};

exports.default = (0, _recompose.compose)((0, _reactCssThemr.themr)('ContactForm', defaultStyles, { composeTheme: 'softly' }), (0, _recompose.withReducer)('state', 'dispatch', reducer, { error: defaultError, isValid: false }))(ContactForm);